# -*- coding: utf-8 -*-
# Copyright 2024 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.contact_center_insights import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.contact_center_insights_v1.services.contact_center_insights.async_client import (
    ContactCenterInsightsAsyncClient,
)
from google.cloud.contact_center_insights_v1.services.contact_center_insights.client import (
    ContactCenterInsightsClient,
)
from google.cloud.contact_center_insights_v1.types.contact_center_insights import (
    BulkAnalyzeConversationsMetadata,
    BulkAnalyzeConversationsRequest,
    BulkAnalyzeConversationsResponse,
    BulkDeleteConversationsMetadata,
    BulkDeleteConversationsRequest,
    BulkDeleteConversationsResponse,
    BulkDownloadFeedbackLabelsMetadata,
    BulkDownloadFeedbackLabelsRequest,
    BulkDownloadFeedbackLabelsResponse,
    BulkUploadFeedbackLabelsMetadata,
    BulkUploadFeedbackLabelsRequest,
    BulkUploadFeedbackLabelsResponse,
    CalculateIssueModelStatsRequest,
    CalculateIssueModelStatsResponse,
    CalculateStatsRequest,
    CalculateStatsResponse,
    ConversationView,
    CreateAnalysisOperationMetadata,
    CreateAnalysisRequest,
    CreateAnalysisRuleRequest,
    CreateConversationRequest,
    CreateFeedbackLabelRequest,
    CreateIssueModelMetadata,
    CreateIssueModelRequest,
    CreatePhraseMatcherRequest,
    CreateQaQuestionRequest,
    CreateQaScorecardRequest,
    CreateQaScorecardRevisionRequest,
    CreateViewRequest,
    DeleteAnalysisRequest,
    DeleteAnalysisRuleRequest,
    DeleteConversationRequest,
    DeleteFeedbackLabelRequest,
    DeleteIssueModelMetadata,
    DeleteIssueModelRequest,
    DeleteIssueRequest,
    DeletePhraseMatcherRequest,
    DeleteQaQuestionRequest,
    DeleteQaScorecardRequest,
    DeleteQaScorecardRevisionRequest,
    DeleteViewRequest,
    DeployIssueModelMetadata,
    DeployIssueModelRequest,
    DeployIssueModelResponse,
    DeployQaScorecardRevisionRequest,
    Dimension,
    ExportInsightsDataMetadata,
    ExportInsightsDataRequest,
    ExportInsightsDataResponse,
    ExportIssueModelMetadata,
    ExportIssueModelRequest,
    ExportIssueModelResponse,
    GetAnalysisRequest,
    GetAnalysisRuleRequest,
    GetConversationRequest,
    GetEncryptionSpecRequest,
    GetFeedbackLabelRequest,
    GetIssueModelRequest,
    GetIssueRequest,
    GetPhraseMatcherRequest,
    GetQaQuestionRequest,
    GetQaScorecardRequest,
    GetQaScorecardRevisionRequest,
    GetSettingsRequest,
    GetViewRequest,
    ImportIssueModelMetadata,
    ImportIssueModelRequest,
    ImportIssueModelResponse,
    IngestConversationsMetadata,
    IngestConversationsRequest,
    IngestConversationsResponse,
    InitializeEncryptionSpecMetadata,
    InitializeEncryptionSpecRequest,
    InitializeEncryptionSpecResponse,
    ListAllFeedbackLabelsRequest,
    ListAllFeedbackLabelsResponse,
    ListAnalysesRequest,
    ListAnalysesResponse,
    ListAnalysisRulesRequest,
    ListAnalysisRulesResponse,
    ListConversationsRequest,
    ListConversationsResponse,
    ListFeedbackLabelsRequest,
    ListFeedbackLabelsResponse,
    ListIssueModelsRequest,
    ListIssueModelsResponse,
    ListIssuesRequest,
    ListIssuesResponse,
    ListPhraseMatchersRequest,
    ListPhraseMatchersResponse,
    ListQaQuestionsRequest,
    ListQaQuestionsResponse,
    ListQaScorecardRevisionsRequest,
    ListQaScorecardRevisionsResponse,
    ListQaScorecardsRequest,
    ListQaScorecardsResponse,
    ListViewsRequest,
    ListViewsResponse,
    QueryMetricsMetadata,
    QueryMetricsRequest,
    QueryMetricsResponse,
    TuneQaScorecardRevisionMetadata,
    TuneQaScorecardRevisionRequest,
    TuneQaScorecardRevisionResponse,
    UndeployIssueModelMetadata,
    UndeployIssueModelRequest,
    UndeployIssueModelResponse,
    UndeployQaScorecardRevisionRequest,
    UpdateAnalysisRuleRequest,
    UpdateConversationRequest,
    UpdateFeedbackLabelRequest,
    UpdateIssueModelRequest,
    UpdateIssueRequest,
    UpdatePhraseMatcherRequest,
    UpdateQaQuestionRequest,
    UpdateQaScorecardRequest,
    UpdateSettingsRequest,
    UpdateViewRequest,
    UploadConversationMetadata,
    UploadConversationRequest,
)
from google.cloud.contact_center_insights_v1.types.resources import (
    Analysis,
    AnalysisResult,
    AnalysisRule,
    AnnotationBoundary,
    AnnotatorSelector,
    AnswerFeedback,
    ArticleSuggestionData,
    CallAnnotation,
    Conversation,
    ConversationDataSource,
    ConversationLevelSentiment,
    ConversationLevelSilence,
    ConversationParticipant,
    ConversationSummarizationSuggestionData,
    DatasetValidationWarning,
    DialogflowIntent,
    DialogflowInteractionData,
    DialogflowSource,
    EncryptionSpec,
    Entity,
    EntityMentionData,
    ExactMatchConfig,
    FaqAnswerData,
    FeedbackLabel,
    GcsSource,
    HoldData,
    Intent,
    IntentMatchData,
    InterruptionData,
    Issue,
    IssueAssignment,
    IssueMatchData,
    IssueModel,
    IssueModelLabelStats,
    IssueModelResult,
    PhraseMatchData,
    PhraseMatcher,
    PhraseMatchRule,
    PhraseMatchRuleConfig,
    PhraseMatchRuleGroup,
    QaAnswer,
    QaQuestion,
    QaScorecard,
    QaScorecardResult,
    QaScorecardRevision,
    RedactionConfig,
    RuntimeAnnotation,
    SentimentData,
    Settings,
    SilenceData,
    SmartComposeSuggestionData,
    SmartReplyData,
    SpeechConfig,
    View,
)

__all__ = (
    "ContactCenterInsightsClient",
    "ContactCenterInsightsAsyncClient",
    "BulkAnalyzeConversationsMetadata",
    "BulkAnalyzeConversationsRequest",
    "BulkAnalyzeConversationsResponse",
    "BulkDeleteConversationsMetadata",
    "BulkDeleteConversationsRequest",
    "BulkDeleteConversationsResponse",
    "BulkDownloadFeedbackLabelsMetadata",
    "BulkDownloadFeedbackLabelsRequest",
    "BulkDownloadFeedbackLabelsResponse",
    "BulkUploadFeedbackLabelsMetadata",
    "BulkUploadFeedbackLabelsRequest",
    "BulkUploadFeedbackLabelsResponse",
    "CalculateIssueModelStatsRequest",
    "CalculateIssueModelStatsResponse",
    "CalculateStatsRequest",
    "CalculateStatsResponse",
    "CreateAnalysisOperationMetadata",
    "CreateAnalysisRequest",
    "CreateAnalysisRuleRequest",
    "CreateConversationRequest",
    "CreateFeedbackLabelRequest",
    "CreateIssueModelMetadata",
    "CreateIssueModelRequest",
    "CreatePhraseMatcherRequest",
    "CreateQaQuestionRequest",
    "CreateQaScorecardRequest",
    "CreateQaScorecardRevisionRequest",
    "CreateViewRequest",
    "DeleteAnalysisRequest",
    "DeleteAnalysisRuleRequest",
    "DeleteConversationRequest",
    "DeleteFeedbackLabelRequest",
    "DeleteIssueModelMetadata",
    "DeleteIssueModelRequest",
    "DeleteIssueRequest",
    "DeletePhraseMatcherRequest",
    "DeleteQaQuestionRequest",
    "DeleteQaScorecardRequest",
    "DeleteQaScorecardRevisionRequest",
    "DeleteViewRequest",
    "DeployIssueModelMetadata",
    "DeployIssueModelRequest",
    "DeployIssueModelResponse",
    "DeployQaScorecardRevisionRequest",
    "Dimension",
    "ExportInsightsDataMetadata",
    "ExportInsightsDataRequest",
    "ExportInsightsDataResponse",
    "ExportIssueModelMetadata",
    "ExportIssueModelRequest",
    "ExportIssueModelResponse",
    "GetAnalysisRequest",
    "GetAnalysisRuleRequest",
    "GetConversationRequest",
    "GetEncryptionSpecRequest",
    "GetFeedbackLabelRequest",
    "GetIssueModelRequest",
    "GetIssueRequest",
    "GetPhraseMatcherRequest",
    "GetQaQuestionRequest",
    "GetQaScorecardRequest",
    "GetQaScorecardRevisionRequest",
    "GetSettingsRequest",
    "GetViewRequest",
    "ImportIssueModelMetadata",
    "ImportIssueModelRequest",
    "ImportIssueModelResponse",
    "IngestConversationsMetadata",
    "IngestConversationsRequest",
    "IngestConversationsResponse",
    "InitializeEncryptionSpecMetadata",
    "InitializeEncryptionSpecRequest",
    "InitializeEncryptionSpecResponse",
    "ListAllFeedbackLabelsRequest",
    "ListAllFeedbackLabelsResponse",
    "ListAnalysesRequest",
    "ListAnalysesResponse",
    "ListAnalysisRulesRequest",
    "ListAnalysisRulesResponse",
    "ListConversationsRequest",
    "ListConversationsResponse",
    "ListFeedbackLabelsRequest",
    "ListFeedbackLabelsResponse",
    "ListIssueModelsRequest",
    "ListIssueModelsResponse",
    "ListIssuesRequest",
    "ListIssuesResponse",
    "ListPhraseMatchersRequest",
    "ListPhraseMatchersResponse",
    "ListQaQuestionsRequest",
    "ListQaQuestionsResponse",
    "ListQaScorecardRevisionsRequest",
    "ListQaScorecardRevisionsResponse",
    "ListQaScorecardsRequest",
    "ListQaScorecardsResponse",
    "ListViewsRequest",
    "ListViewsResponse",
    "QueryMetricsMetadata",
    "QueryMetricsRequest",
    "QueryMetricsResponse",
    "TuneQaScorecardRevisionMetadata",
    "TuneQaScorecardRevisionRequest",
    "TuneQaScorecardRevisionResponse",
    "UndeployIssueModelMetadata",
    "UndeployIssueModelRequest",
    "UndeployIssueModelResponse",
    "UndeployQaScorecardRevisionRequest",
    "UpdateAnalysisRuleRequest",
    "UpdateConversationRequest",
    "UpdateFeedbackLabelRequest",
    "UpdateIssueModelRequest",
    "UpdateIssueRequest",
    "UpdatePhraseMatcherRequest",
    "UpdateQaQuestionRequest",
    "UpdateQaScorecardRequest",
    "UpdateSettingsRequest",
    "UpdateViewRequest",
    "UploadConversationMetadata",
    "UploadConversationRequest",
    "ConversationView",
    "Analysis",
    "AnalysisResult",
    "AnalysisRule",
    "AnnotationBoundary",
    "AnnotatorSelector",
    "AnswerFeedback",
    "ArticleSuggestionData",
    "CallAnnotation",
    "Conversation",
    "ConversationDataSource",
    "ConversationLevelSentiment",
    "ConversationLevelSilence",
    "ConversationParticipant",
    "ConversationSummarizationSuggestionData",
    "DialogflowIntent",
    "DialogflowInteractionData",
    "DialogflowSource",
    "EncryptionSpec",
    "Entity",
    "EntityMentionData",
    "ExactMatchConfig",
    "FaqAnswerData",
    "FeedbackLabel",
    "GcsSource",
    "HoldData",
    "Intent",
    "IntentMatchData",
    "InterruptionData",
    "Issue",
    "IssueAssignment",
    "IssueMatchData",
    "IssueModel",
    "IssueModelLabelStats",
    "IssueModelResult",
    "PhraseMatchData",
    "PhraseMatcher",
    "PhraseMatchRule",
    "PhraseMatchRuleConfig",
    "PhraseMatchRuleGroup",
    "QaAnswer",
    "QaQuestion",
    "QaScorecard",
    "QaScorecardResult",
    "QaScorecardRevision",
    "RedactionConfig",
    "RuntimeAnnotation",
    "SentimentData",
    "Settings",
    "SilenceData",
    "SmartComposeSuggestionData",
    "SmartReplyData",
    "SpeechConfig",
    "View",
    "DatasetValidationWarning",
)
